@@ -8,9 +8,10 @@ __all__ = ["begin", "begin0", "lazy_begin", "lazy_begin0",
 
 from collections import namedtuple
 from unpythonic.env import env
+from unpythonic.misc import call
 
 # evil inspect dependency, used only to provide informative error messages.
-from unpythonic.arity import arity_includes
+from unpythonic.arity import arity_includes, UnknownArity
 
 # sequence side effects in a lambda
 def begin(*vals):
@@ -137,11 +138,11 @@ def pipe(value0, *bodys):
         x = update(x)
     return x
 
-class get:  # sentinel singleton with a nice repr
+@call  # make a singleton
+class get:  # sentinel with a nice repr
     """Sentinel; pipe into this to exit a shell-like pipe and return the current value."""
     def __repr__(self):
         return "<sentinel for pipe exit>"
-get = get()
 
 class piped:
     """Shell-like piping syntax.
@@ -218,12 +219,12 @@ class lazy_piped:
             assert lst == [1, 2, 3]  # now the side effect has updated lst.
 
             # lazy pipe as an unfold
-            fibos = [1, 1]
+            fibos = []
             def nextfibo(state):
                 a, b = state
-                fibos.append(a + b)  # store result by side effect
+                fibos.append(a)      # store result by side effect
                 return (b, a + b)    # new state, handed to next function in the pipe
-            p = lazy_piped(fibos)    # load initial state into a lazy pipe
+            p = lazy_piped((1, 1))   # load initial state into a lazy pipe
             for _ in range(10):      # set up pipeline
                 p = p | nextfibo
             p | get  # run it
@@ -310,8 +311,11 @@ def do(*items):
     e = env()
     def maybe_call(v):
         if callable(v):
-            if not arity_includes(v, 1):
-                raise ValueError("Arity mismatch; callable value must allow arity 1, to take in the environment.")
+            try:
+                if not arity_includes(v, 1):
+                    raise ValueError("Arity mismatch; callable value must allow arity 1, to take in the environment.")
+            except UnknownArity:  # well, we tried!
+                pass
             return v(e)
         else:
             return v
@@ -391,12 +395,12 @@ def test():
     assert lst == [1, 2, 3]  # now the side effect has updated lst.
 
     # lazy pipe as an unfold
-    fibos = [1, 1]
+    fibos = []
     def nextfibo(state):
         a, b = state
-        fibos.append(a + b)  # store result by side effect
+        fibos.append(a)      # store result by side effect
         return (b, a + b)    # new state, handed to next function in the pipe
-    p = lazy_piped(fibos)    # load initial state into a lazy pipe
+    p = lazy_piped((1, 1))   # load initial state into a lazy pipe
     for _ in range(10):      # set up pipeline
         p = p | nextfibo
     p | get  # run it
